@@ -105,14 +105,8 @@ static void php_swoole_http_response_free_object(zend_object *object) {
             } else
 #endif
             {
-                if (ctx->co_socket) {
+                if (ctx->is_available()) {
                     ctx->end(nullptr, &ztmp);
-                } else {
-                    Server *serv = (Server *) ctx->private_data;
-                    Connection *conn = serv->get_connection_by_session_id(ctx->fd);
-                    if (conn && !conn->closed && !conn->peer_closed) {
-                        ctx->end(nullptr, &ztmp);
-                    }
                 }
             }
         }
@@ -1390,7 +1384,8 @@ static PHP_METHOD(swoole_http_response, create) {
     sw_copy_to_stack(ctx->response.zobject, ctx->response._zobject);
     zend_update_property_long(swoole_http_response_ce, SW_Z8_OBJ_P(return_value), ZEND_STRL("fd"), fd);
     if (ctx->co_socket) {
-        zend_update_property(swoole_http_response_ce, SW_Z8_OBJ_P(ctx->response.zobject), ZEND_STRL("socket"), zobject);
+        zend_update_property_ex(
+            swoole_http_response_ce, SW_Z8_OBJ_P(ctx->response.zobject), SW_ZSTR_KNOWN(SW_ZEND_STR_SOCKET), zobject);
     }
     if (zrequest) {
         zend_update_property_long(swoole_http_request_ce, SW_Z8_OBJ_P(ctx->request.zobject), ZEND_STRL("fd"), fd);
