@@ -10,7 +10,7 @@
  | to obtain it through the world-wide-web, please send a note to       |
  | license@swoole.com so we can mail you a copy immediately.            |
  +----------------------------------------------------------------------+
- | Author: Tianfeng Han  <mikan.tenny@gmail.com>                        |
+ | Author: Tianfeng Han  <rango@swoole.com>                             |
  +----------------------------------------------------------------------+
  */
 
@@ -269,27 +269,24 @@ bool ProcessFactory::end(SessionId session_id, int flags) {
     DataHead ev = {};
 
     /**
-     * Only active shutdown needs to determine whether it is in the process of connection binding
+     * Only close actively needs to determine whether it is in the process of connection binding.
+     * If the worker process is not currently bound to this connection,
+     * MUST forward to the correct worker process
      */
     if (conn->close_actively) {
-        /**
-         * The worker process is not currently bound to this connection,
-         * and needs to be forwarded to the correct worker process
-         */
-        int worker_id = server_->is_hash_dispatch_mode() ? server_->schedule_worker(conn->fd, nullptr)
-                                                         : conn->fd % server_->worker_num;
         if (server_->last_stream_socket) {
             goto _close;
         }
-        if (server_->is_worker() && worker_id == (int) SwooleG.process_id) {
+        bool hash = server_->is_hash_dispatch_mode();
+        int worker_id = hash ? server_->schedule_worker(conn->fd, nullptr) : conn->fd % server_->worker_num;
+        if (server_->is_worker() && (!hash || worker_id == (int) SwooleG.process_id)) {
             goto _close;
-        } else {
-            worker = server_->get_worker(worker_id);
-            ev.type = SW_SERVER_EVENT_CLOSE;
-            ev.fd = session_id;
-            ev.reactor_id = conn->reactor_id;
-            return server_->send_to_worker_from_worker(worker, &ev, sizeof(ev), SW_PIPE_MASTER) > 0;
         }
+        worker = server_->get_worker(worker_id);
+        ev.type = SW_SERVER_EVENT_CLOSE;
+        ev.fd = session_id;
+        ev.reactor_id = conn->reactor_id;
+        return server_->send_to_worker_from_worker(worker, &ev, sizeof(ev), SW_PIPE_MASTER) > 0;
     }
 
 _close:
